
==============================
Continuum Mechanics' tutorials
==============================

Here we show how to use `continuum_mechanics'` capabilities through
tutorials.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   tutorials/curvilinear_coordinates
   tutorials/point_source_halfspace
   tutorials/dispersion_micropolar
